@@ -19,7 +19,7 @@ def get_deployed():
     Returns:
         List of Models.
     """
-    return [Model.load(x) for x in api_get('api/models/deployments')]
+    return [Model.load(x) for x in api_get('models/deployments/api')]
 
 class Model(ApiObject):
     """Base class for all models."""
@@ -39,7 +39,7 @@ class Model(ApiObject):
         Returns:
             Model.
         """
-        return Model.load(api_get(f'api/models/{model_id}'))
+        return Model.load(api_get(f'models/{model_id}/api'))
 
     @staticmethod
     def load(entry) -> Union[TabularClassifier, TabularRegressor]:
@@ -53,10 +53,10 @@ class Model(ApiObject):
 
     def refresh(self) -> None:
         """reloads model."""
-        self.update(api_get(f'api/models/{self.model_id}'))
+        self.update(api_get(f'models/{self.model_id}/api'))
 
     def tag(self, tag: str) -> None:
-        self.update(api_post(f'api/models/{self.model_id}/tag', tag))
+        self.update(api_post(f'models/{self.model_id}/tag/api', tag))
 
     def deploy(self, wait: bool = True) -> None:
         """
@@ -71,7 +71,7 @@ class Model(ApiObject):
         if self.status != 'stopped':
             raise RuntimeError('status must be stopped')
 
-        self.update(api_post(f'api/models/{self.model_id}/deployment'))
+        self.update(api_post(f'models/{self.model_id}/deployment/api'))
 
         if wait:
             while self.status == 'pending_deployment':
@@ -91,7 +91,7 @@ class Model(ApiObject):
         if self.status != 'running':
             raise RuntimeError('status must be running')
 
-        self.update(api_delete(f'api/models/{self.model_id}/deployment'))
+        self.update(api_delete(f'models/{self.model_id}/deployment/api'))
 
         if wait:
             while self.status == 'pending_discharge':
@@ -112,7 +112,7 @@ class Model(ApiObject):
         if self.status != 'running':
             raise RuntimeError('status must be running')
 
-        return api_put(f'api/models/{self.model_id}/predictions/{prediction_id}', data = json.dumps(actual))
+        return api_put(f'models/{self.model_id}/predictions/{prediction_id}/api', data = json.dumps(actual))
 
     def derive_task(self, method: str = 'auto', value: Optional[Union[float, int]] = None) -> Task:
         """
@@ -157,7 +157,7 @@ class Model(ApiObject):
             payload['value'] = value
 
         from .task import Task
-        return Task(api_post(f'api/models/{self.model_id}/tasks', json=payload))
+        return Task(api_post(f'models/{self.model_id}/tasks/api', json=payload))
 
     def _predict(self, data, prediction_method):
         if self.status != 'running':
@@ -166,7 +166,7 @@ class Model(ApiObject):
         if prediction_method not in self.prediction_methods:
             raise NotImplementedError(f'{prediction_method} not implemented in model')
 
-        return api_post(f'api/models/{self.model_id}/predictions', data = json.dumps(dict(data = data, prediction_method = prediction_method)))
+        return api_post(f'models/{self.model_id}/predictions/api', data = json.dumps(dict(data = data, prediction_method = prediction_method)))
 
     def _predict_batch(self, data, prediction_method, upload_func):
         if self.status != 'running':
@@ -178,7 +178,7 @@ class Model(ApiObject):
         files = upload_func(data)
         payload = dict(prediction_method = prediction_method, files = files)
 
-        return api_post(f'api/models/{self.model_id}/batch', data = json.dumps(payload))
+        return api_post(f'models/{self.model_id}/batch/api', data = json.dumps(payload))
 
 
 class TabularClassifier(Model):
