@@ -1,9 +1,14 @@
 """Various analytics tools."""
 import numpy as np
 import pandas as pd
+
+from typing import Optional, Union
+
 from sklearn.utils import check_random_state
 
-def calculate_metric_stats(y, pred, metric, num_samples = None, num_repeats = 1000):
+from ..base.metric import Metric
+
+def calculate_metric_stats(y: Union[np.array, pd.DataFrame], pred: Union[np.array, pd.DataFrame], metric: Metric, num_samples: Optional[int] = None, num_repeats: int = 1000) -> dict:
     """
     Calculate metric stats.
 
